#!/bin/sh
# Copyright (c) 2000-2023 Synology Inc. All rights reserved.

source /usr/syno/etc/rc.sysv/syno_bundle_firmware_upgrade_shared.sh
RedirectLogIfExist() {
	file="$1"

	if ! test -f "${file}"; then
		return 0
	fi

	/bin/logger --tag "$(/bin/basename "$0")" --priority user.warn "${file}:"
	while read -r line; do
		/bin/logger --tag "$(/bin/basename "$0")" --priority user.warn "${line}"
	done < "${file}"

	rm "${file}"
}

MonitorSHAFWUpg() {
	timeout=yes

	if ! test -f "/var/lib/drive-bundle/start-sha-result-monitor"; then
		# for general reboot case
		return 0
	fi

	for i in $(seq 1 1200); do	# for the case, upgrading without keeping role, it needs to wait the passive reboot
		if ! synoha --is-ha-upgrading; then
			timeout=no
			break
		fi
		sleep 1
	done

	if [ "Active" != "$(synoha --local-role)" ]; then
		return 0
	fi

	synofwupgrade $timeout
}

RedirectLogIfExist "/var/lib/drive-bundle/download-fw-without-timeout.log"
RedirectLogIfExist "/var/lib/drive-bundle/gen-conf.log"
RedirectLogIfExist "/var/lib/drive-bundle/upgrade.log"

statePath="/var/run/drive-bundle/upgrade_state"
if [ -f "${statePath}" ]; then
	state="$(synogetkeyvalue "$statePath" upgrade_state)"
	if [ "post_handle" = "${state}" ]; then
		/usr/syno/bin/syno_drive_bundle --upgrade-firmware --force-upgrade-post-handle
	fi
fi

if [ "yes" != "$(/usr/syno/sbin/synohacore --is_ha_running)" ]; then
	exit 0
fi

if [ "yes" = "$(/usr/syno/bin/synogetkeyvalue /etc.defaults/synoinfo.conf support_xa)" ]; then
	exit 0
fi

MonitorSHAFWUpg
RemoveUnusedFile
